@@ -52,10 +52,10 @@ ServiceViewer::ServiceViewer(Plasma::DataEngine *engine, const QString &source,
     QString serviceName = i18nc("Plasma service with unknown name", "Unknown");
 
     if (m_engine) {
-        if (m_engine->pluginInfo().isValid()) {
-            engineName = KStringHandler::capwords(m_engine->pluginInfo().name());
+        if (m_engine->metadata().isValid()) {
+            engineName = KStringHandler::capwords(m_engine->metadata().name());
         }
-        qDebug() << "########### CALLING SERVICE FOR SOURCE: " << m_source;
+        qDebug() << "Requesting service for source" << m_source;
         m_service = m_engine->serviceForSource(m_source);
 
         if (m_service != nullptr) {
@@ -72,7 +72,7 @@ ServiceViewer::ServiceViewer(Plasma::DataEngine *engine, const QString &source,
     setWindowTitle(i18nc("%1 is a Plasma service name", "%1 Service Explorer", serviceName));
 
     QString title = i18nc("Source: name of the data, Service: writes data instead of fetching",
-                          "DataEngine: <b>%1</b>; Source: <b>%2</b>; Service: <b>%3</b>",
+                          "Engine: <b>%1</b>; Source: <b>%2</b>; Service: <b>%3</b>",
                           engineName,
                           m_source,
                           serviceName);
@@ -103,7 +103,7 @@ void ServiceViewer::updateOperations()
         if (!operations.isEmpty()) {
             enable = true;
 
-            foreach (const QString &operation, operations) {
+            for (const QString &operation : operations) {
                 m_operations->addItem(operation);
             }
         }
@@ -155,7 +155,7 @@ void ServiceViewer::operationSelected(const QString &operation)
     int i = 0;
     const QStringList keys = desc.keys();
     m_operationDescription->setRowCount(keys.count());
-    foreach (const QString &key, keys) {
+    for (const QString &key : keys) {
         QTableWidgetItem *item = new QTableWidgetItem(key);
         item->setFlags(Qt::ItemIsSelectable | Qt::ItemIsEnabled);
         m_operationDescription->setItem(i, 0, item);
